@@ -1,10 +1,9 @@
 package File::NCopy;
-require 5.004; # just because I think you should upgrade :)
+use 5.004; # just because I think you should upgrade :)
 
 =head1 NAME
 
-B<File::NCopy> - Copy file, file
-              Copy file[s] | dir[s], dir
+File::NCopy - Deprecated module. Use File::Copy::Recursive instead. Copy file, file. Copy file[s] | dir[s], dir
 
 =head1 SYNOPSIS
 
@@ -159,9 +158,13 @@ follow circular or dead links.  This is really a feature though the
 result may not quite resemble the source dir, the overall content will
 be the same. :)
 
+From Ken Healy (Version 0.34)
+
+On Win32, The use of backslash for paths is required.
+
 =head1 AUTHOR
 
-Gabor Egressy B<gabor@vmunix.com>
+Gabor Egressy B<gabor AT vmunix.com>
 
 Copyright (c) 1998 Gabor Egressy.  All rights reserved.  All wrongs
 reversed.  This program is free software; you can redistribute and/or
@@ -170,7 +173,9 @@ modify it under the same terms as Perl itself.
 Some ideas gleaned from File::Copy by Aaron Sherman & Charles Bailey,
 but the code was written from scratch.
 
-Patch at version 0.33 added by MZSANFORD.
+Patch at versions 0.33, and 0.34 added by MZSANFORD.
+
+0.35 - Alexandr Ciornii (alexchorny AT gmail.com)
 
 =cut
 
@@ -182,7 +187,7 @@ use vars qw(@EXPORT_OK @ISA $VERSION);
 # we export nothing by default :)
 @EXPORT_OK = qw(copy cp);
 
-$VERSION = '0.33';
+$VERSION = '0.35';
 
 # this works on Unix
 sub u_chmod($$)
@@ -321,8 +326,6 @@ NO_FILE:
     }
 
     $this->{'set_permission'}->($file_from,$file_to);
-    $this->{'set_times'}->($file_from,$file_to)
-        if $this->{'preserve'};
 
     # we only close files we opened
     unless ($this->{test}) {
@@ -332,6 +335,10 @@ NO_FILE:
         unless ref $file_to eq 'GLOB' || ref $file_to eq 'FileHandle';
     }
 
+    # this was moved from above the unless statement per Ken Healy in version 0.34
+    $this->{'set_times'}->($file_from,$file_to)
+        if $this->{'preserve'};
+
     print "$file_from ==> $file_to\n"
         if $this->{'_debug'};
 
@@ -399,7 +406,7 @@ sub _recurse_from_dir($$$)
     for (@files) {
         next
             if /^\.\.?$/;
-        if(-f "$from_dir/$_") {
+        if(-f $from_dir . $dir_sep . $_) {
             $ret = _docopy_file_file $this, $from_dir . $dir_sep . $_ ,
                     $to_dir . $dir_sep . $_;
         }
@@ -485,7 +492,7 @@ sub _docopy_file_dir($$$)
     
     $dir =~ s/$dir_sep$//; # remove trailing slash 
 
-    _docopy_file_file $this, $file,$dir.'/'.$file_to;
+    _docopy_file_file $this, $file,$dir.$dir_sep.$file_to;
 }
 
 # this just redirects calls, like copy ;)
@@ -532,7 +539,7 @@ sub expand(@)
     @args;
 }
 
-sub new(@);
+sub new(@); #prototype
 
 # this just redirects calls
 sub copy(@)
@@ -555,7 +562,7 @@ sub copy(@)
     my @copies;
     my @args = expand @_;
 
-    print "passed args ==> @args\n"
+    print "passed args ==> ".join(',',map {"'$_'"} @args)."\n"
         if $this->{'_debug'};
 
     # one or more files/directories to a directory
